# Rormula

[![CI](https://github.com/basf/rormula/actions/workflows/ci.yml/badge.svg)](https://github.com/basf/rormula/actions)
[![PyPI](https://img.shields.io/pypi/v/rormula.svg?color=%2334D058)](https://pypi.org/project/rormula)

Rormula is a Python package that parses the Wilkinson notation to create model matrices useful in design of experiments. 
Additionally, it can be used for column arithmetics similar to
`df.eval` where `df` is a Pandas dataframe. Rormula is significantly faster for small matrices than `df.eval` or [Formulaic](https://github.com/matthewwardrop/formulaic)
and still a not well tested prototype.

More information can be found under https://github.com/basf/rormula.
